{ pkgs, lib, ... }:
{
  imports = [
    ./neovim.nix
    ./zsh.nix
  ];

  home = {
    packages = with pkgs; [
      bat
      bottom
      # ncdu
      neofetch
      pwgen
      sshfs
      sshuttle
      tmux
    ];

    sessionVariables = {
      EDITOR = "nvim";
      VISUAL = "nvim";
    };
  };

  programs.nix-index = {
    enable = true;
    enableZshIntegration = true;
  };

  programs.fzf.enable = true;

  programs.git = {
    enable = true;

    extraConfig = {
      pull.rebase = true;
      push.autoSetupRemote = true;
      color.ui = "auto";
      init.defaultBranch = "main";
      lfs.enable = true;

      user = {
        name = "Felix Albrigtsen";
        email = lib.mkDefault "felix@albrigtsen.it";
      };
      safe = {
        directory = "/config";
      };
    };
    ignores = [
      "*~"
      "*.swp"
      ".DS_Store"
      ".vscode"
    ];
  };

}
