{ config, pkgs, lib, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
      ./desktop.nix
  ];

  networking = {
    hostName = "sisko";
    defaultGateway = "192.168.10.1";
    interfaces.enp14s0 = {
      ipv4 = {
        addresses = [
          { address = "192.168.10.172"; prefixLength = 24; }
        ];
      };
      wakeOnLan.enable = true;
    };
    hostId = "b716d781";
  };

  hardware.bluetooth.enable = true;
  sops.defaultSopsFile = ../../secrets/sisko/sisko.yaml;
  environment.variables = { EDITOR = "vim"; };

  users.users.felixalb.extraGroups = [ "dialout" ];

  programs = {
    gamemode.enable = true;
    steam = {
      enable = true;
      remotePlay.openFirewall = true;
    };

    alvr = {
      enable = true;
      package = pkgs.unstable.alvr;
      openFirewall = true;
    };

    firefox = {
      enable = true;
      nativeMessagingHosts.tridactyl = true;
    };
  };

  nixpkgs.config = {
    allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
      "copilot.vim"
      "discord"
      "spotify"
      "steam"
      "steam-unwrapped"
      "tlclient"
    ];
  };


  services.fwupd.enable = true;
  system.stateVersion = "24.11";
}

